@@ -22,6 +22,7 @@ import beaker.ext.sqla as sqla
 import beaker.ext.google as google
 import beaker.ext.mongodb as mongodb
 import beaker.ext.redisnm as redisnm
+import beaker.ext.redisclusternm as redisclusternm
 from functools import wraps
 
 # Initialize the cache region dict
@@ -126,7 +127,8 @@ clsmap = _backends({
     'ext:sqla': sqla.SqlaNamespaceManager,
     'ext:google': google.GoogleNamespaceManager,
     'ext:mongodb': mongodb.MongoNamespaceManager,
-    'ext:redis': redisnm.RedisNamespaceManager
+    'ext:redis': redisnm.RedisNamespaceManager,
+    'ext:rediscluster': redisclusternm.RedisClusterNamespaceManager,
 })
 
 
@@ -176,7 +178,7 @@ def cache_region(region, *args):
     :param region: String name of the region corresponding to the desired
       caching arguments, established in :attr:`.cache_regions`.
 
-    :param \*args: Optional ``str()``-compatible arguments which will uniquely
+    :param *args: Optional ``str()``-compatible arguments which will uniquely
       identify the key used by this decorated function, in addition
       to the positional arguments passed to the function itself at call time.
       This is recommended as it is needed to distinguish between any two functions
